/*
 * Copyright (c) 2018 Jan Van Winkel <jan.van_winkel@dxplore.eu>
 *
 * SPDX-License-Identifier: Apache-2.0
 */

#include <device.h>
#include <drivers/display.h>
#include <lvgl.h>
#include <stdio.h>
#include <string.h>
#include <zephyr.h>
#include <drivers/sensor.h>
#include <sys/util.h>

#define LOG_LEVEL CONFIG_LOG_DEFAULT_LEVEL
#include <logging/log.h>
LOG_MODULE_REGISTER(app);
extern lv_font_t robotomonolight_55;

void main(void)
{
	uint32_t count = 0U;
	char count_str[11] = {0};
	const struct device *display_dev;
	lv_obj_t *hello_world_label;
	lv_obj_t *count_label;

	//======================================================================
	struct sensor_value pressure, temp;
	volatile double pressuremBar;
	double pressurekPa;
    const struct device *dev = DEVICE_DT_GET(DT_INST(0,st_lps22df_press));
	    if (dev == NULL) {
		    LOG_ERR("Could not get LPS22DF device\n");
		    return;
	    }
	//======================================================================

	display_dev = DEVICE_DT_GET(DT_CHOSEN(zephyr_display));
	if (!device_is_ready(display_dev)) {
		LOG_ERR("Device not ready, aborting test");
		return;
	}

	if (IS_ENABLED(CONFIG_LV_Z_POINTER_KSCAN)) {
		lv_obj_t *hello_world_button;

		hello_world_button = lv_btn_create(lv_scr_act());
		lv_obj_align(hello_world_button, LV_ALIGN_CENTER, 0, 0);
		hello_world_label = lv_label_create(hello_world_button);
	} else {
		hello_world_label = lv_label_create(lv_scr_act());
	}
	static lv_style_t style;
	lv_style_set_text_font(&style, &robotomonolight_55);
	lv_obj_set_style_text_font(hello_world_label,&robotomonolight_55, LV_PART_MAIN);
	lv_obj_set_style_text_color(hello_world_label,lv_color_black(), LV_PART_MAIN);
	lv_label_set_text(hello_world_label, "TEST0");
	lv_obj_align(hello_world_label, LV_ALIGN_CENTER, 0, 0);

	count_label = lv_label_create(lv_scr_act());
	lv_obj_align(count_label, LV_ALIGN_BOTTOM_LEFT, 0, 0);

	lv_task_handler();
	display_blanking_off(display_dev);

	while (1) {
		if ((count % 100) == 0U) {
			if (sensor_sample_fetch(dev) < 0) {
				LOG_ERR("Sensor sample update error\n");
				return;
			}

			if (sensor_channel_get(dev, SENSOR_CHAN_PRESS, &pressure) < 0) {
				LOG_ERR("Cannot read LPS22HB pressure channel\n");
				return;
			}

			if (sensor_channel_get(dev, SENSOR_CHAN_AMBIENT_TEMP, &temp) < 0) {
				LOG_ERR("Cannot read LPS22HB temperature channel\n");
				return;
			}
			pressurekPa = sensor_value_to_double(&pressure);
			pressuremBar = pressurekPa*10.0;
			sprintf(count_str,"Pressure:%.3f kPa\n", pressuremBar);
			//LOG_INF()
			//sprintf(count_str, "%d", count/100U);
			lv_label_set_text(count_label, count_str);
		}
		lv_task_handler();
		k_sleep(K_MSEC(10));
		++count;
	}
}
